==> nextcloud-30.0.12.tar.bz2: nextcloud/lib/l10n/he.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "לא ניתן לכתוב לתיקיית „config”!",
    "See %s" : "יש לעיין ב־%s",
    "Sample configuration detected" : "התגלתה דוגמת תצורה",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "התגלה שדוגמת התצורה הועתקה. דבר זה עלול לשבור את ההתקנה ולא נתמך.יש לקרוא את מסמכי התיעוד לפני שמבצעים שינויים ב- config.php",
    "Other activities" : "פעילויות אחרות",
    "Enterprise bundle" : "מהדורה מסחרית",
    "Groupware bundle" : "מהדורה קבוצתית",
    "Social sharing bundle" : "מאגד שיתוף חברתי",
    "PHP %s or higher is required." : "נדרש PHP בגרסת %s ומעלה.",
    "PHP with a version lower than %s is required." : "נדרש PHP בגרסה נמוכה מ- %s.",
    "%sbit or higher PHP required." : "נדרש PHP בגרסת %s ומעלה.",
    "The following architectures are supported: %s" : "קיימת תמיכה בתצורות המעבדים הבאות: %s",
    "The following databases are supported: %s" : "יש תמיכה במסדי הנתונים הבאים: %s",
    "The command line tool %s could not be found" : "כלי שורת הפקודה %s לא אותר",
    "The library %s is not available." : "הספריה %s אינה זמינה.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "נדרשת ספרייה %1$s עם גרסה מתחת ל־%2$s - הגרסה הזמינה היא %3$s.",
    "The following platforms are supported: %s" : "קיימת תמיכה בפלטפורמות הבאות: %s",
    "Server version %s or higher is required." : "נדרשת גרסה שרת %s ומעלה.",
    "Server version %s or lower is required." : "נדרשת גרסה שרת %s ומטה.",
    "Authentication" : "אימות",
    "Unknown filetype" : "סוג קובץ לא מוכר",
    "Invalid image" : "תמונה לא חוקית",
    "Avatar image is not square" : "התמונה המייצגת אינה מרובעת",
    "Files" : "קבצים",
    "_%nh_::_%nh_" : ["שעה","שעתיים","%n שע׳"],
    "today" : "היום",
    "tomorrow" : "מחר",
    "yesterday" : "אתמול",
    "_in %n day_::_in %n days_" : ["בעוד יום","בעוד יומיים","בעוד %n ימים","בעוד %n ימים"],
    "_%n day ago_::_%n days ago_" : ["לפני %n יום","לפני %n ימים","לפני %n ימים","לפני %n ימים"],
    "next month" : "בחודש הבא",
    "last month" : "חודש שעבר",
    "_in %n month_::_in %n months_" : ["בעוד חודש","בעוד חודשיים","בעוד %n חודשים"],
    "_%n month ago_::_%n months ago_" : ["לפני חודש","לפני חודשיים","לפני %n חודשים"],
    "next year" : "בשנה הבאה",
    "last year" : "שנה שעברה",
    "_in %n year_::_in %n years_" : ["בעוד שנה","בעוד שנתיים","בעוד %n שנים","בעוד %n שנים"],
    "_%n year ago_::_%n years ago_" : ["לפני %n שנה","לפני %n שנים","לפני %n שנים","לפני %n שנים"],
    "_in %n hour_::_in %n hours_" : ["בעוד שעה","בעוד שעתיים","בעוד %n שעות","בעוד %n שעות"],
    "_%n hour ago_::_%n hours ago_" : ["לפני שעה","לפני שעתיים","לפני %n שעות"],
    "_in %n minute_::_in %n minutes_" : ["בעוד דקה","בעוד 2 דקות","בעוד %n דקות","בעוד %n דקות"],
    "_%n minute ago_::_%n minutes ago_" : ["לפני דקה","לפני 2 דקות","לפני %n דקות","לפני %n דקות"],
    "in a few seconds" : "בעוד מספר שניות",
    "seconds ago" : "לפני מספר שניות",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "המודול עם המזהה: %s לא קיים. נא להפעיל אותו בהגדרות היישומונים שלך או ליצור קשר עם מנהל המערכת.",
    "Dot files are not allowed" : "אסור ששמות קבצים יתחילו בנקודה",
    "File already exists" : "הקובץ כבר קיים",
    "Filename contains at least one invalid character" : "שם הקובץ מכיל לפחות תו אחד שגוי",
    "Empty filename is not allowed" : "שם קובץ ריק אינו מאושר",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "יישום \"%s\" לא ניתן להתקנה כיוון שקובץ appinfo לא ניתן לקריאה.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "לא ניתן להתקין את היישומון „%s” כיוון שאין לו תמיכה בגרסה זו של השרת.",
    "__language_name__" : "עברית",
    "This is an automatically sent email, please do not reply." : "זו הודעת דוא״ל שנשלחה אוטומטית, נא לא להגיב.",
    "Appearance and accessibility" : "תצוגה ונגישות",
    "Apps" : "יישומים",
    "Settings" : "הגדרות",
    "Log out" : "התנתק",
    "Email" : "דוא״ל",
    "Phone" : "טלפון",
    "Twitter" : "טוויטר",
    "Website" : "אתר אינטרנט",
    "Address" : "כתובת",
    "Profile picture" : "תמונת פרופיל",
    "About" : "על אודות",
    "Additional settings" : "הגדרות נוספות",
    "You need to enter details of an existing account." : "עליך להקליד פרטים של חשבון קיים.",
    "Oracle connection could not be established" : "לא ניתן היה ליצור חיבור Oracle",
    "For the best results, please consider using a GNU/Linux server instead." : "לתוצאות הכי טובות, יש לשקול שימוש בשרת GNU/Linux במקום.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "נראה ש- %s עובד על בסיס סביבת 32-bit PHP ושה- open_basedir הוגדר בקובץ php.ini. מצב זה יוביל לבעיות עם קבצים הגדולים מ- 4 GB ואינו מומלץ לחלוטין.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "יש להסיר את הגדרת open_basedir מתוך קובץ php.ini או להחליף לסביבת 64-bit PHP.",
    "Set an admin password." : "קביעת סיסמת מנהל",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "צד אחורי לשיתוף %s חייב ליישם את ממשק OCP\\Share_Backend",
    "Sharing backend %s not found" : "צד אחורי לשיתוף %s לא נמצא",
    "Sharing backend for %s not found" : "צד אחורי לשיתוף של %s לא נמצא",
    "%1$s via %2$s" : "%1$s דרך %2$s",
    "Unknown share type" : "סוג שיתוף אינו מוכר",
    "You are not allowed to share %s" : "אינך רשאי/ת לשתף %s",
    "Cannot increase permissions of %s" : "לא ניתן להוסיף על ההרשאות של %s",
    "Expiration date is in the past" : "תאריך תפוגה הנו בעבר",
    "The requested share does not exist anymore" : "השיתוף המבוקש אינו קיים עוד",
    "Could not find category \"%s\"" : "לא ניתן למצוא את הקטגוריה „%s“",
    "Sunday" : "יום ראשון",
    "Monday" : "יום שני",
    "Tuesday" : "יום שלישי",
    "Wednesday" : "יום רביעי",
    "Thursday" : "יום חמישי",
    "Friday" : "יום שישי",
    "Saturday" : "שבת",
    "Sun." : "ראשון",
    "Mon." : "שני",
    "Tue." : "שלישי",
    "Wed." : "רביעי",
    "Thu." : "חמישי",
    "Fri." : "שישי",
    "Sat." : "שבת",
    "Su" : "א",
    "Mo" : "ב",
    "Tu" : "ג",
    "We" : "ד",
    "Th" : "ה",
    "Fr" : "ו",
    "Sa" : "ש",
    "January" : "ינואר",
    "February" : "פברואר",
    "March" : "מרץ",
    "April" : "אפריל",
    "May" : "מאי",
    "June" : "יוני",
    "July" : "יולי",
    "August" : "אוגוסט",
    "September" : "ספטמבר",
    "October" : "אוקטובר",
    "November" : "נובמבר",
    "December" : "דצמבר",
    "Jan." : "ינו׳",
    "Feb." : "פבר׳",
    "Mar." : "מרץ",
    "Apr." : "אפר׳",
    "May." : "מאי",
    "Jun." : "יונ׳",
    "Jul." : "יול׳",
    "Aug." : "אוג׳",
    "Sep." : "ספט׳",
    "Oct." : "אוק׳",
    "Nov." : "נוב׳",
    "Dec." : "דצמ׳",
    "A valid password must be provided" : "יש לספק ססמה תקנית",
    "Login canceled by app" : "התחברות בוטלה על ידי יישום",
    "a safe home for all your data" : "בית בטוח עבור כל המידע שלך",
    "Application is not enabled" : "יישומים אינם מופעלים",
    "Authentication error" : "שגיאת הזדהות",
    "Token expired. Please reload page." : "פג תוקף. נא לטעון שוב את הדף.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "לא מותקנים דרייברים למסד הנתונים (sqlite, mysql, או postgresql).",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "או, אם עדיף לך לשמור על config.php לקריאה בלבד, ניתן להגדיר את האפשרות „config_is_read_only” לערך true. נא לעיין ב־%s",
    "PHP module %s not installed." : "מודול PHP %s אינו מותקן.",
    "Please ask your server administrator to install the module." : "יש לבקש ממנהל השרת שלך להתקין את המודול.",
    "PHP setting \"%s\" is not set to \"%s\"." : "הגדרות PHP \"%s\" אינם מוגדרות ל- \"%s\"",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "התאמת ההגדרה הזו ב־php.ini יאפשר ל־Nextcloud לפעול שוב",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP ככל הנראה מוגדר ל- strip inline doc blocks. זה יגרום למספר יישומי ליבה לא להיות נגישים.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "זה ככל הנראה נגרם על ידי מאיץ/מטמון כמו Zend OPcache או eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "מודולי PHP הותקנו, אך עדיין רשומים כחסרים?",
    "Please ask your server administrator to restart the web server." : "יש לבקש ממנהל השרת שלך להפעיל מחדש את שרת האינטרנט.",
    "Action \"%s\" not supported or implemented." : "הפעולה „%s” אינה נתמכת או שאינה מוטמעת.",
    "Authentication failed, wrong token or provider ID given" : "האימות נכשל, האסימון או מזהה הספק שסופקו שגויים",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "חסרים משתנים להשלמת הבקשה. המשתנים החסרים: „%s”",
    "Could not obtain lock type %d on \"%s\"." : "לא ניתן היה להשיג סוג נעילה %d ב- \"%s\".",
    "Storage unauthorized. %s" : "אחסון לא מורשה. %s",
    "Storage incomplete configuration. %s" : "תצורה לא מושלמת של האחסון. %s",
    "Storage connection error. %s" : "שגיאת חיבור אחסון. %s",
    "Storage is temporarily not available" : "האחסון אינו זמין כרגע",
    "Storage connection timeout. %s" : "פסק זמן חיבור אחסון. %s",
    "Text" : "טקסט",
    "Summary" : "תקציר",
    "Translate" : "תרגום",
    "Result" : "תוצאה",
    "File is currently busy, please try again later" : "הקובץ בשימוש כרגע, יש לנסות שוב מאוחר יותר"
},
"nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");

==> nextcloud-31.0.14.tar.bz2: nextcloud/lib/l10n/he.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "לא ניתן לכתוב לתיקיית „config”!",
    "See %s" : "יש לעיין ב־%s",
    "Sample configuration detected" : "התגלתה דוגמת תצורה",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "התגלה שדוגמת התצורה הועתקה. דבר זה עלול לשבור את ההתקנה ולא נתמך.יש לקרוא את מסמכי התיעוד לפני שמבצעים שינויים ב- config.php",
    "Other activities" : "פעילויות אחרות",
    "Enterprise bundle" : "מהדורה מסחרית",
    "Groupware bundle" : "מהדורה קבוצתית",
    "Social sharing bundle" : "מאגד שיתוף חברתי",
    "PHP %s or higher is required." : "נדרש PHP בגרסת %s ומעלה.",
    "PHP with a version lower than %s is required." : "נדרש PHP בגרסה נמוכה מ- %s.",
    "%sbit or higher PHP required." : "נדרש PHP בגרסת %s ומעלה.",
    "The following architectures are supported: %s" : "קיימת תמיכה בתצורות המעבדים הבאות: %s",
    "The following databases are supported: %s" : "יש תמיכה במסדי הנתונים הבאים: %s",
    "The command line tool %s could not be found" : "כלי שורת הפקודה %s לא אותר",
    "The library %s is not available." : "הספריה %s אינה זמינה.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "נדרשת ספרייה %1$s עם גרסה מתחת ל־%2$s - הגרסה הזמינה היא %3$s.",
    "The following platforms are supported: %s" : "קיימת תמיכה בפלטפורמות הבאות: %s",
    "Server version %s or higher is required." : "נדרשת גרסה שרת %s ומעלה.",
    "Server version %s or lower is required." : "נדרשת גרסה שרת %s ומטה.",
    "Authentication" : "אימות",
    "Unknown filetype" : "סוג קובץ לא מוכר",
    "Invalid image" : "תמונה לא חוקית",
    "Avatar image is not square" : "התמונה המייצגת אינה מרובעת",
    "Files" : "קבצים",
    "_%nh_::_%nh_" : ["שעה","שעתיים","%n שע׳"],
    "today" : "היום",
    "tomorrow" : "מחר",
    "yesterday" : "אתמול",
    "_in %n day_::_in %n days_" : ["בעוד יום","בעוד יומיים","בעוד %n ימים","בעוד %n ימים"],
    "_%n day ago_::_%n days ago_" : ["לפני %n יום","לפני %n ימים","לפני %n ימים","לפני %n ימים"],
    "next month" : "בחודש הבא",
    "last month" : "חודש שעבר",
    "_in %n month_::_in %n months_" : ["בעוד חודש","בעוד חודשיים","בעוד %n חודשים"],
    "_%n month ago_::_%n months ago_" : ["לפני חודש","לפני חודשיים","לפני %n חודשים"],
    "next year" : "בשנה הבאה",
    "last year" : "שנה שעברה",
    "_in %n year_::_in %n years_" : ["בעוד שנה","בעוד שנתיים","בעוד %n שנים","בעוד %n שנים"],
    "_%n year ago_::_%n years ago_" : ["לפני %n שנה","לפני %n שנים","לפני %n שנים","לפני %n שנים"],
    "_in %n hour_::_in %n hours_" : ["בעוד שעה","בעוד שעתיים","בעוד %n שעות","בעוד %n שעות"],
    "_%n hour ago_::_%n hours ago_" : ["לפני שעה","לפני שעתיים","לפני %n שעות"],
    "_in %n minute_::_in %n minutes_" : ["בעוד דקה","בעוד 2 דקות","בעוד %n דקות","בעוד %n דקות"],
    "_%n minute ago_::_%n minutes ago_" : ["לפני דקה","לפני 2 דקות","לפני %n דקות","לפני %n דקות"],
    "in a few seconds" : "בעוד מספר שניות",
    "seconds ago" : "לפני מספר שניות",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "המודול עם המזהה: %s לא קיים. נא להפעיל אותו בהגדרות היישומונים שלך או ליצור קשר עם מנהל המערכת.",
    "Dot files are not allowed" : "אסור ששמות קבצים יתחילו בנקודה",
    "File already exists" : "הקובץ כבר קיים",
    "Filename contains at least one invalid character" : "שם הקובץ מכיל לפחות תו אחד שגוי",
    "Empty filename is not allowed" : "שם קובץ ריק אינו מאושר",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "יישום \"%s\" לא ניתן להתקנה כיוון שקובץ appinfo לא ניתן לקריאה.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "לא ניתן להתקין את היישומון „%s” כיוון שאין לו תמיכה בגרסה זו של השרת.",
    "__language_name__" : "עברית",
    "This is an automatically sent email, please do not reply." : "זו הודעת דוא״ל שנשלחה אוטומטית, נא לא להגיב.",
    "Appearance and accessibility" : "תצוגה ונגישות",
    "Apps" : "יישומים",
    "Settings" : "הגדרות",
    "Log out" : "התנתק",
    "Accounts" : "Accounts",
    "Email" : "דוא״ל",
    "Phone" : "טלפון",
    "Twitter" : "טוויטר",
    "Website" : "אתר אינטרנט",
    "Address" : "כתובת",
    "Profile picture" : "תמונת פרופיל",
    "About" : "על אודות",
    "Additional settings" : "הגדרות נוספות",
    "You need to enter details of an existing account." : "עליך להקליד פרטים של חשבון קיים.",
    "Oracle connection could not be established" : "לא ניתן היה ליצור חיבור Oracle",
    "For the best results, please consider using a GNU/Linux server instead." : "לתוצאות הכי טובות, יש לשקול שימוש בשרת GNU/Linux במקום.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "נראה ש- %s עובד על בסיס סביבת 32-bit PHP ושה- open_basedir הוגדר בקובץ php.ini. מצב זה יוביל לבעיות עם קבצים הגדולים מ- 4 GB ואינו מומלץ לחלוטין.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "יש להסיר את הגדרת open_basedir מתוך קובץ php.ini או להחליף לסביבת 64-bit PHP.",
    "Set an admin password." : "קביעת סיסמת מנהל",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "צד אחורי לשיתוף %s חייב ליישם את ממשק OCP\\Share_Backend",
    "Sharing backend %s not found" : "צד אחורי לשיתוף %s לא נמצא",
    "Sharing backend for %s not found" : "צד אחורי לשיתוף של %s לא נמצא",
    "%1$s via %2$s" : "%1$s דרך %2$s",
    "Unknown share type" : "סוג שיתוף אינו מוכר",
    "You are not allowed to share %s" : "אינך רשאי/ת לשתף %s",
    "Cannot increase permissions of %s" : "לא ניתן להוסיף על ההרשאות של %s",
    "Expiration date is in the past" : "תאריך תפוגה הנו בעבר",
    "The requested share does not exist anymore" : "השיתוף המבוקש אינו קיים עוד",
    "Could not find category \"%s\"" : "לא ניתן למצוא את הקטגוריה „%s“",
    "Sunday" : "יום ראשון",
    "Monday" : "יום שני",
    "Tuesday" : "יום שלישי",
    "Wednesday" : "יום רביעי",
    "Thursday" : "יום חמישי",
    "Friday" : "יום שישי",
    "Saturday" : "שבת",
    "Sun." : "ראשון",
    "Mon." : "שני",
    "Tue." : "שלישי",
    "Wed." : "רביעי",
    "Thu." : "חמישי",
    "Fri." : "שישי",
    "Sat." : "שבת",
    "Su" : "א",
    "Mo" : "ב",
    "Tu" : "ג",
    "We" : "ד",
    "Th" : "ה",
    "Fr" : "ו",
    "Sa" : "ש",
    "January" : "ינואר",
    "February" : "פברואר",
    "March" : "מרץ",
    "April" : "אפריל",
    "May" : "מאי",
    "June" : "יוני",
    "July" : "יולי",
    "August" : "אוגוסט",
    "September" : "ספטמבר",
    "October" : "אוקטובר",
    "November" : "נובמבר",
    "December" : "דצמבר",
    "Jan." : "ינו׳",
    "Feb." : "פבר׳",
    "Mar." : "מרץ",
    "Apr." : "אפר׳",
    "May." : "מאי",
    "Jun." : "יונ׳",
    "Jul." : "יול׳",
    "Aug." : "אוג׳",
    "Sep." : "ספט׳",
    "Oct." : "אוק׳",
    "Nov." : "נוב׳",
    "Dec." : "דצמ׳",
    "A valid password must be provided" : "יש לספק ססמה תקנית",
    "Login canceled by app" : "התחברות בוטלה על ידי יישום",
    "a safe home for all your data" : "בית בטוח עבור כל המידע שלך",
    "Application is not enabled" : "יישומים אינם מופעלים",
    "Authentication error" : "שגיאת הזדהות",
    "Token expired. Please reload page." : "פג תוקף. נא לטעון שוב את הדף.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "לא מותקנים דרייברים למסד הנתונים (sqlite, mysql, או postgresql).",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "או, אם עדיף לך לשמור על config.php לקריאה בלבד, ניתן להגדיר את האפשרות „config_is_read_only” לערך true. נא לעיין ב־%s",
    "PHP module %s not installed." : "מודול PHP %s אינו מותקן.",
    "Please ask your server administrator to install the module." : "יש לבקש ממנהל השרת שלך להתקין את המודול.",
    "PHP setting \"%s\" is not set to \"%s\"." : "הגדרות PHP \"%s\" אינם מוגדרות ל- \"%s\"",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "התאמת ההגדרה הזו ב־php.ini יאפשר ל־Nextcloud לפעול שוב",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP ככל הנראה מוגדר ל- strip inline doc blocks. זה יגרום למספר יישומי ליבה לא להיות נגישים.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "זה ככל הנראה נגרם על ידי מאיץ/מטמון כמו Zend OPcache או eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "מודולי PHP הותקנו, אך עדיין רשומים כחסרים?",
    "Please ask your server administrator to restart the web server." : "יש לבקש ממנהל השרת שלך להפעיל מחדש את שרת האינטרנט.",
    "Action \"%s\" not supported or implemented." : "הפעולה „%s” אינה נתמכת או שאינה מוטמעת.",
    "Authentication failed, wrong token or provider ID given" : "האימות נכשל, האסימון או מזהה הספק שסופקו שגויים",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "חסרים משתנים להשלמת הבקשה. המשתנים החסרים: „%s”",
    "Could not obtain lock type %d on \"%s\"." : "לא ניתן היה להשיג סוג נעילה %d ב- \"%s\".",
    "Storage unauthorized. %s" : "אחסון לא מורשה. %s",
    "Storage incomplete configuration. %s" : "תצורה לא מושלמת של האחסון. %s",
    "Storage connection error. %s" : "שגיאת חיבור אחסון. %s",
    "Storage is temporarily not available" : "האחסון אינו זמין כרגע",
    "Storage connection timeout. %s" : "פסק זמן חיבור אחסון. %s",
    "Images" : "תמונות",
    "Optical character recognition" : "זיהוי תווים אופטי",
    "Text" : "טקסט",
    "Summary" : "תקציר",
    "Translate" : "תרגום",
    "Result" : "תוצאה"
},
"nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
